View source: R/checkInputDataCV.R
| checkInputDataCV | R Documentation |
Internal helper function to validate the arguments specific to cv.srlars
(share_grid and outer_folds), on top of the shared srlars argument
checks performed by checkInputData.
checkInputDataCV(share_grid, n_models, outer_folds)
share_grid |
Integer vector of candidate |
n_models |
Number of models in the ensemble. |
outer_folds |
Number of outer cross-validation folds. |
NULL. Stops execution with an error message if invalid inputs are detected.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.